%% mydata_Rhizoglyphus_robini: Female Bulb Mite (untransformed data)
% Tom van den Beuken and Lars Kramer 2015/3/31, template:mydata_Clione_limacina.m by Jaap van der Meer

%% References
% Complex Environmental effects of the expression of alternative reproductive phenotypes in the bulb mite, supplementary material, Smallegange (2011)
% Unpublished data, van den Beuken (2015) 
%% Facts
% Two Alternative reproductive phenotypes of the male can be distinguishe; a so-called 'sneaker' and 'fighter' male. The two differ morphologically, behaviourally and possibly physiologically. Differentiation between the two is dependent on energy budgets. 
% Here we focus on the female first.
% Because the females body length varies with the production of eggs from puberty onwards there are three different datasets incorporated in the analysis: no transformation of length, a static transformation on length, a transformation on length dependent on the production of eggs(given by Sma).  
% Zero variate data vary dependent on the dataset used; change zero variate values accordingly!

COMPLETE = 2.5;   % judge the level using LikaKear2011; adjust if you have less or more data
%FIT = 8.8;        % compute after having obtained the estimates
                      
  global dwm % pass d_O, w_O, mu_O directly to predict_Rhizoglyphus_robini

% set data

% zero-variate data
% real data
ab = 2.6;  % 1  d, age at birth at f (sma)
   T_ab = 273 + 27; % K, temperature for ab (sma)
ap = 9;  %  2 d, age at puberty at f  (sma)
  T_ap = 273 + 27; % K, temperature for ap (sma)
am = 43;   %  3 d, life span at f (sma)
  T_am = 273 + 27; % K, temperature for am (sma)
Lb = 0.0192;       %  4 cm, physical length at birth at f (sma)

% Values for untransformed data (comment/uncomment whichever is appropriate) 
    %Lp = 0.04306725;     %  5, length at puberty (sma dataset fitted to nls-model)
    %Li = 0.1008;     %  6 cm, ultimate physical length at f (sma, maximum value of the dataset)
    %Wwp = 219.38*10^-6;   %  7 g, ultimate wet weight at f (Beu)

% Values for transformed data (comment/uncomment whichever is appropriate)
    Lp = 0.03220482;     %  5, length at puberty (sma dataset fitted to nls-model)
    Li = 0.08533;     %  6 cm, ultimate physical length at f (sma, maximum value of the dataset)
    Wwp = 219.38*10^-6;   %  7 g, ultimate wet weight at f (Beu)

Ri = 26.3; %  8 #/d, maximum reproduction rate at f (sma)
%Peak reproduction rate is much higher (up to 50), however due to senecence the average Ri over the adult stage better describes reproduction. 
  T_Ri = 273 + 27; % K, temperature for Ri (sma)

% initial estimates from the get_pars_s script with temperature conforming to the input data 
v = 0.003;     %  9 cm/d, energy conductance (guess based on get_pars_s script)
kap = 0.0909;    % 10 -, allocation fraction to soma = growth + somatic maintenance (estimate by get_pars_s script)
kap_R = 0.95; % 11 -, reproduction efficiency 
p_M = 400;     % 12 J/d.cm^3, [p_M] vol-specific somatic maintenance (estimate by get_pars_s script and value of daphnia)
p_T =  0;     % 13 J/d.cm^2, {p_T} surface-specific som maintenance
k_J = 0.00001;  % 14 1/d, maturity maintenance rate coefficient (estimate by get_pars_s script)
kap_G = .8;   % 15 -, growth efficiency

% pack data  
data = [ab; ap; am; Lb; Lp; Li; Wwp; Ri;         % 01:08 real data
        v; kap; kap_R; p_M; p_T; k_J; kap_G];   % 09:15 pseudo data

% weight coefficients for WLS and ML criteria differ
Data = [data(:,[1 1]), min(100,1 ./ max(1e-6, data) .^ 2)]; % nmregr, nrregr (WLS criterion)
Data(1:8,3) = 100 * Data(1:8,3); % give real data more weight 

%Data(7,3) = 0 * Data(7,3); %mute the ultimate wetweight in the case of use of the transformed data

% insert temperature data for rates and times in the first column
Data([1 2 3 8], 1) = [T_ab; T_ap; T_am; T_Ri];

txt_data = {... % for presentation of predictions
    '1 ab, d, age at birth ';
    '2 ap, d, age at puberty ';
    '3 am, d, life span ';
    '4 Lb, cm, total length at birth ';
    '5 Lp, cm, total length at puberty ';
    '6 Li, cm, ultimate total length ';
    '7 Wi, g, ultimate wet weight ';
    '8 Ri, #/d, maximum reprod rate ';
    '9 v, cm/d, energy conductance ';
   '10 kap, -, allocation fraction to soma ';
   '11 kap_R, -, reproduction efficiency ';
   '12 [p_M], J/d.cm^3, vol-spec som maint ';
   '13 {p_T}, J/d.cm^2, sur-spec som maint ';
   '14 k_J, 1/d, maturity maint rate coefficient ';
   '15 kap_G, -, growth efficiency'};

% uni-variate data at f = 1 and T = 273 + 27 
%  t-L-data
tL = [2.526315789	183	183; 2.526315789	185	185; 2.526315789	194	194;
2.526315789	195	195; 1.526315789	197	197; 2.526315789	205	205;
2.526315789	205	205; 2.526315789	205	205; 5.526315789	205	205;
2.526315789	208	208; 2.526315789	214	214; 2.526315789	218	218;
2.526315789	221	221; 2.526315789	235	235; 3.526315789	239	239;
3.526315789	257	257; 3.526315789	263	263; 3.526315789	264	264;
3.526315789	264	264; 3.526315789	268	268; 2.526315789	274	274;
3.526315789	286	286; 4.526315789	290	290; 4.526315789	291	291;
5.526315789	292	292; 4.526315789	299	299; 4.526315789	300	300;
5.526315789	301	301; 4.526315789	304	304; 4.526315789	304	304;
4.526315789	307	307; 4.526315789	307	307; 6.526315789	319	319;
4.526315789	320	320; 4.526315789	369	369; 4.526315789	256	256;
5.526315789	312	312; 5.526315789	313	313; 3.526315789	314	314;
5.526315789	338	338; 4.526315789	349	349; 6.526315789	352	352;
5.526315789	354	354; 5.526315789	366	366; 5.526315789	376	376;
5.526315789	377	377; 5.526315789	383	383; 5.526315789	385	385;
5.526315789	385	385; 6.526315789	393	393; 5.526315789	396	396;
5.526315789	396	396; 5.526315789	402	402; 5.526315789	412	412;
6.526315789	415	415; 6.526315789	424	424; 7.526315789	427	427;
6.526315789	427	427; 6.526315789	431	431; 5.526315789	435	435;
6.526315789	436	436; 7.526315789	439	439;6.526315789	448	448;
6.526315789	449	449; 6.526315789	450	450; 5.526315789	461	461;
6.526315789	461	461; 6.526315789	473	473; 4.526315789	340	340;
6.526315789	431	431; 7.526315789	447	447; 6.526315789	453	453;
7.526315789	462	462; 4.526315789	470	470; 7.526315789	487	487;
8.526315789	495	495; 5.526315789	496	496; 7.526315789	515	515;
7.526315789	524	524; 6.526315789	525	525; 7.526315789	537	537;
7.526315789	537	537; 8.526315789	540	540; 7.526315789	545	545;
7.526315789	558	558; 8.526315789	588	588; 8.526315789	607	607;
8.526315789	622	622; 8.526315789	634	634; 8.526315789	654	654;
8.526315789	658	658; 8.526315789	666	666; 9.526315789	671	671;
8.526315789	673	673; 7.526315789	719	719; 11.52631579	614.2 428.4220613;
11.52631579	614.2 428.4220613; 11.52631579	614.2	428.4220613;
11.52631579	614.2	428.4220613; 11.52631579	614.2	428.4220613;
10.52631579	644.6	455.1832084; 10.52631579	644.6	455.1832084;
10.52631579	644.6	455.1832084; 10.52631579	644.6	455.1832084;
9.526315789	657	466.1748794; 9.526315789	657	466.1748794;
9.526315789	657	466.1748794; 9.526315789	657	466.1748794;
9.526315789	657	466.1748794; 9.526315789	657	466.1748794;
9.526315789	657	466.1748794; 9.526315789	657	466.1748794;
9.526315789	657	466.1748794; 9.526315789	658	467.0908735;
9.526315789	658	467.0908735; 9.526315789	658	467.0908735;
9.526315789	658	467.0908735; 9.526315789	658	467.0908735;
9.526315789	672	479.9874905; 9.526315789	672	479.9874905;
9.526315789	672	479.9874905; 10.52631579	672	480.1689622;
10.52631579	672	480.1689622; 9.526315789	679	486.4888019;
9.526315789	679	486.4888019; 10.52631579	679	486.6313762;
10.52631579	679	486.6313762; 10.52631579	679	486.6313762;
10.52631579	679	486.6313762; 10.52631579	679	486.6313762;
9.526315789	688	494.902473; 9.526315789	688	494.902473;
9.526315789	688	494.902473; 9.526315789	688	494.902473;
9.526315789	688	494.902473; 9.526315789	688	494.902473;
9.526315789	688	494.902473; 9.526315789	696	502.435387;
10.52631579	696	502.4731279; 10.52631579	696	502.4731279;
10.52631579	696	502.4731279; 10.52631579	696	502.4731279;
10.52631579	696	502.4731279; 10.52631579	696	502.4731279;
10.52631579	696	502.4731279; 10.52631579	696	502.4731279;
9.526315789	710	515.7475105; 9.526315789	710	515.7475105;
9.526315789	710	515.7475105; 9.526315789	710	515.7475105;
9.526315789	710	515.7475105; 9.526315789	710	515.7475105;
10.52631579	713.9	519.396799; 10.52631579	713.9	519.3967979;
10.52631579	713.9	519.3967979; 10.52631579	713.9	519.3967979;
10.52631579	713.9	519.3967979; 10.52631579	713.9	519.3967979;
10.52631579	713.9	519.3967979; 10.52631579	713.9	519.3967979;
9.526315789	716	521.5057395; 9.526315789	716	521.5057395;
9.526315789	716	521.5057395; 9.526315789	716	521.5057395;
9.526315789	716	521.5057395; 9.526315789	716	521.5057395;
9.526315789	716	521.5057395; 9.526315789	716	521.5057395;
9.526315789	716	521.5057395; 9.526315789	716	521.5057395;
9.526315789	717	522.4686539; 10.52631579	724.5	529.546082;
10.52631579	724.5	529.54608; 10.52631579	724.5	529.546082;
10.52631579	724.5	529.546082; 10.52631579	724.5	529.546082;
10.52631579	724.5	529.546082; 10.52631579	724.5	529.546082;
11.52631579	729.3	534.0307834; 11.52631579	729.3	534.0307834;
11.52631579	729.3	534.0307834; 11.52631579	729.3	534.0307834;
11.52631579	729.3	534.0307834; 11.52631579	729.3	534.0307834;
11.52631579	729.3	534.0307834; 11.52631579	729.3	534.0307834;
10.52631579	739	543.5949981; 10.52631579	739	543.5949981;
10.52631579	739	543.5949981; 10.52631579	741	545.5484971;
10.52631579	741	545.5484971; 10.52631579	741	545.5484971;
10.52631579	741	545.5484971; 10.52631579	741	545.5484971;
11.52631579	744.3	548.5079526; 11.52631579	744.3	548.5079526;
11.52631579	744.3	548.5079526; 11.52631579	744.3	548.5079526;
11.52631579	744.3	548.5079526; 11.52631579	744.3	548.5079526;
11.52631579	744.3	548.5079526; 11.52631579	744.3	548.5079526;
11.52631579	744.3	548.5079526; 9.526315789	746	550.8181737;
9.526315789	746	550.8181737; 9.526315789	746	550.8181737;
9.526315789	746	550.8181737; 9.526315789	746	550.8181737;
9.526315789	746	550.8181737; 9.526315789	746	550.8181737;
9.526315789	746	550.8181737; 9.526315789	747	551.811205;
9.526315789	747	551.811205; 9.526315789	747	551.811205;
9.526315789	747	551.811205; 9.526315789	747	551.811205;
9.526315789	747	551.811205; 9.526315789	747	551.811205;
8.526315789	751	556.300543; 10.52631579	752	556.3641242;
10.52631579	752	556.3641242; 10.52631579	752	556.3641242;
10.52631579	752	556.3641242; 10.52631579	752	556.3641242;
10.52631579	752	556.3641242; 10.52631579	752	556.3641242;
9.526315789	754	558.7931581; 9.526315789	754	558.7931581;
9.526315789	754	558.7931581; 9.526315789	754	558.7931581;
9.526315789	754	558.7931581; 9.526315789	754	558.7931581;
9.526315789	754	558.7931581; 9.526315789	754	558.7931581;
9.526315789	754	558.7931581; 11.52631579	755.2	559.1587563;
11.52631579	755.2	559.1587563; 11.52631579	755.2	559.1587563;
11.52631579	755.2	559.1587563; 10.52631579	761	565.3065528;
10.52631579	761	565.3065528; 10.52631579	761	565.3065528;
10.52631579	761	565.3065528; 10.52631579	761	565.3065528;
10.52631579	761	565.3065528; 10.52631579	761	565.3065528;
10.52631579	761	565.3065528; 10.52631579	761	565.3065528;
9.526315789	762	566.8402108; 10.52631579	765.3	569.6099201;
10.52631579	765.3	569.6099201; 9.526315789	767	571.9075382;
11.52631579	769	572.812028; 10.52631579	772	576.3563091;
10.52631579	772	576.3563091; 10.52631579	772	576.3563091;
10.52631579	772	576.3563091; 10.52631579	772	576.3563091;
10.52631579	772	576.3563091; 10.52631579	772	576.3563091;
10.52631579	772	576.3563091; 10.52631579	772	576.3563091;
11.52631579	778.4	582.2263827; 11.52631579	778.4	582.2263827;
11.52631579	778.4	582.2263827; 11.52631579	778.4	582.2263827;
11.52631579	778.4	582.2263827; 11.52631579	778.4	582.2263827;
9.526315789	786	591.4441554; 11.52631579	787.2	591.1283226;
11.52631579	787.2	591.1283226; 11.52631579	787.2	591.1283226;
11.52631579	787.2	591.1283226; 11.52631579	787.2	591.1283226;
11.52631579	787.2	591.1283226; 9.526315789	793	598.759868;
9.526315789	793	598.759868; 9.526315789	793	598.759868;
9.526315789	793	598.759868; 9.526315789	793	598.759868;
9.526315789	793	598.759868; 9.526315789	793	598.759868;
9.526315789	793	598.759868; 9.526315789	793	598.759868;
10.52631579	797.5	602.5201682; 10.52631579	797.5	602.5201682;
10.52631579	797.5	602.5201682; 10.52631579	797.5	602.5201682;
10.52631579	797.5	602.5201682; 10.52631579	797.5	602.5201682;
10.52631579	797.5	602.5201682; 10.52631579	800	605.1292399;
10.52631579	803	608.2710298; 10.52631579	803	608.2710298;
10.52631579	803	608.2710298; 10.52631579	803	608.2710298;
10.52631579	803	608.2710298; 10.52631579	803	608.2710298;
9.526315789	819	626.5388637; 9.526315789	820	627.6274561;
11.52631579	823.9	629.2638539; 11.52631579	823.9	629.2638539;
11.52631579	823.9	629.2638539; 12.52631579	837	642.0071541;
10.52631579	847	655.8332812; 10.52631579	847.5	656.3909765;
10.52631579	847.5	656.3909765; 10.52631579	847.5	656.3909765;
10.52631579	847.5	656.3909765; 10.52631579	847.5	656.3909765;
10.52631579	847.5	656.3909765; 11.52631579	847.5	654.7501751;
11.52631579	847.5	654.7501751; 11.52631579	847.5	654.7501751;
11.52631579	847.5	654.7501751; 9.526315789	849	659.9083272;
11.52631579	852	659.7046262; 11.52631579	855	663.0252976;
8.526315789	894	716.1918994; 9.526315789	900	720.485749;
5.526315789	638.2	448.08493; 5.526315789	668.2	476.1357716;
5.526315789	671	478.7945394; 5.526315789	673	480.6981955;
5.526315789	673	480.6981955; 5.526315789	681	488.3515318;
5.526315789	685.3	492.491479; 5.526315789	689	496.0689043;
5.526315789	689.1	496.1657888; 5.526315789	704.3	511.0172748;
5.526315789	712.2	518.8384819; 6.526315789	715.9	522.1367934;
5.526315789	716.5	523.1264938; 23.52631579	716.7	525.517042;
38.52631579	734	551.8881292; 5.526315789	734.1	540.9168843;
24.52631579	734.2	541.7040105; 5.526315789	736.4	543.2714429;
5.526315789	740.2	547.1772496; 12.52631579	741.5	545.6171923;
20.52631579	744.2	549.0053857; 5.526315789	745.1	552.2430572;
5.526315789	746.7	553.9044941; 26.52631579	748	555.1623927;
10.52631579	749.8	554.1911559; 11.52631579	751.5	555.5305411;
5.526315789	755.4	563.0031058; 16.52631579	756	559.2070678;
47.52631579	756.3	580.1928232; 5.526315789	759.9	567.7531851;
19.52631579	762.2	565.3277896; 29.52631579	764.2	571.4546656;
31.52631579	764.8	573.342117; 25.52631579	769.1	573.6203361;
17.52631579	769.8	572.2560666; 13.52631579	770.3	573.3201449;
44.52631579	773.5	592.3469735; 37.52631579	774	586.2314918;
18.52631579	775.3	577.4691408; 30.52631579	780.1	586.2954246;
5.526315789	782.5	592.0907485; 32.52631579	782.9	590.149857;
22.52631579	783.5	585.6914111; 30.52631579	783.5	589.3357408;
15.52631579	785	587.0835147; 23.52631579	785.1	587.4377095;
43.52631579	785.4	601.8614838; 6.526315789	786.7	595.3808347;
6.526315789	789.1	597.9918344; 18.52631579	790.4	591.7771462;
13.52631579	792	594.7695523; 8.526315789	793.6	600.4352269;
6.526315789	796.6	606.2131073; 40.52631579	797.5	609.6831285;
33.52631579	797.7	604.0528439; 50.52631579	798.2	620.452474;
51.52631579	798.2	621.5418699; 52.52631579	798.2	622.6403099;
53.52631579	798.2	623.7468333; 54.52631579	798.2	624.860523;
55.52631579	798.2	625.9805039; 56.52631579	798.2	627.1059407;
12.52631579	799.5	602.9519738; 51.52631579	799.6	622.7853417;
52.52631579	799.6	623.8850817; 53.52631579	799.6	624.9930018;
11.52631579	800.1	604.340558; 19.52631579	800.5	601.3292633;
6.526315789	801.3	611.414092; 45.52631579	805.1	621.2817282;
5.526315789	808	620.6070539; 9.526315789	808.5	615.2011189;
12.52631579	809.5	613.1971555; 39.52631579	809.7	619.5739152;
10.52631579	810.6	616.2846191; 30.52631579	810.8	613.8579349;
20.52631579	810.9	611.1655379; 20.52631579	811.8	612.0224621;
13.52631579	812.4	615.3731194; 12.52631579	812.6	616.3972246;
36.52631579	812.7	619.6923622; 9.526315789	813.4	620.4712766;
25.52631579	813.8	614.4498228; 15.52631579	815.5	617.1779975;
11.52631579	815.5	620.3825933; 46.52631579	815.6	631.6091142;
6.526315789	816.8	628.8464576; 8.526315789	816.9	625.6717797;
12.52631579	817.6	621.5833291; 10.52631579	818	624.1644895;
5.526315789	818.1	632.2429961; 15.52631579	818.1	619.7841726;
11.52631579	819.4	624.4941712; 26.52631579	820.2	620.6425371;
18.52631579	820.4	620.6892047; 31.52631579	820.6	623.2704652;
32.52631579	820.6	623.8768985; 33.52631579	821.1	624.9765764;
25.52631579	821.1	621.1980171; 20.52631579	821.2	621.0050958;
19.52631579	821.2	621.1916949; 26.52631579	821.4	621.7476367;
31.52631579	822	624.5332826; 19.52631579	822.7	622.6431113;
9.526315789	824.5	632.5455732; 11.52631579	824.6	630.0083014;
11.52631579	824.9	630.327558; 29.52631579	825.1	626.2939292;
16.52631579	825.7	626.809557; 12.52631579	825.8	630.1563046;
29.52631579	826	627.1128756; 5.526315789	827.3	643.0235893;
10.52631579	827.4	634.2882558; 5.526315789	827.6	643.3781398;
30.52631579	828.6	629.9604438; 8.526315789	831.4	641.8235115;
9.526315789	832.2	641.0364441; 11.52631579	832.3	638.2425152;
17.52631579	832.5	633.0366183; 23.52631579	832.5	631.5797006;
30.52631579	833.3	634.2283477; 48.52631579	834	650.0451798;
6.526315789	834.1	648.8437362; 31.52631579	835	636.2857115;
30.52631579	835.5	636.2284886; 18.52631579	835.7	635.7076699;
10.52631579	837.1	644.8749362; 33.52631579	837.4	639.6248947;
23.52631579	837.8	636.5906784; 13.52631579	838.1	642.0050026;
8.526315789	838.8	650.2085323; 23.52631579	839.3	638.0118578;
46.52631579	839.6	652.8824064; 16.52631579	839.6	640.8052799;
36.52631579	839.9	643.9556562; 12.52631579	840	645.2102136;
17.52631579	840.5	641.0314353; 15.52631579	840.6	642.6293276;
13.52631579	841	645.0612247; 26.52631579	841.1	639.9797701;
12.52631579	841.5	646.8164084; 29.52631579	841.7	641.4436372;
26.52631579	842	640.8168993; 30.52631579	843	643.0588898;
16.52631579	843.3	644.5636608; 26.52631579	843.3	642.0267531;
30.52631579	843.5	643.5149049; 19.52631579	844.8	644.2303134;
5.526315789	845.1	664.4042265; 24.52631579	845.2	643.593697;
47.52631579	845.5	659.1759444; 11.52631579	845.6	652.6677233;
24.52631579	846	644.3493578; 31.52631579	846	646.268523;
17.52631579	846.3	646.8657669; 44.52631579	847.3	657.6612651;
19.52631579	847.5	646.8947882; 5.526315789	848.1	668.0789754;
10.52631579	848.1	657.0607589; 26.52631579	848.5	646.8741393;
11.52631579	849.2	656.6181453; 10.52631579	849.4	658.514013;
45.52631579	849.8	660.8960759; 16.52631579	851.3	652.7390721;
16.52631579	851.4	652.8416981; 27.52631579	851.8	650.1353738;
8.526315789	851.9	665.3013964; 18.52631579	852.1	652.0311885;
9.526315789	852.7	664.1314033; 33.52631579	853.1	653.7956596;
24.52631579	853.4	651.356406; 27.52631579	853.6	651.8088108;
22.52631579	853.6	651.8035859; 11.52631579	854.1	662.0275936;
24.52631579	854.9	652.7805888; 19.52631579	855.7	655.024942;
15.52631579	856	658.5867177; 15.52631579	857.2	659.8417868;
11.52631579	858.2	666.5832224; 15.52631579	858.3	660.993785;
24.52631579	858.9	656.5848499; 8.526315789	858.9	673.5026947;
8.526315789	859.2	673.8563722; 17.52631579	860.6	661.3931874;
44.52631579	860.7	669.5642417; 12.52631579	860.9	667.8808485;
9.526315789	862.1	674.9739678; 9.526315789	862.4	675.3227509;
10.52631579	862.9	673.7761648; 27.52631579	863	660.5718426;
24.52631579	863.5	660.9715027; 17.52631579	864	664.8782348;
8.526315789	864	679.5402069; 18.52631579	864.5	664.5388124;
8.526315789	864.7	680.3730668; 8.526315789	864.9	680.611214;
26.52631579	865.3	662.625107; 30.52631579	865.3	663.4802841;
9.526315789	865.7	679.1707989; 9.526315789	865.8	679.2877356;
20.52631579	865.9	664.6050915; 10.52631579	865.9	677.2112404;
21.52631579	866	664.2060408; 16.52631579	866	667.9439676;
10.52631579	866.1	677.4408225; 16.52631579	866.1	668.0482405;
30.52631579	867.7	665.6885944; 12.52631579	867.9	675.6199593;
37.52631579	868.1	669.9780697; 16.52631579	868.7	670.7634173;
12.52631579	869.1	676.9543617; 25.52631579	869.3	666.4123542;
31.52631579	870	668.1803341; 13.52631579	870.1	676.356361;
41.52631579	870.2	675.1609786; 11.52631579	871.1	681.0973523;
37.52631579	871.1	672.6724019; 10.52631579	871.5	683.6671809;
18.52631579	872.2	672.3813767; 16.52631579	872.2	674.4309932;
14.52631579	872.3	677.1946618; 38.52631579	872.3	674.5089149;
12.52631579	872.3	680.5239783; 25.52631579	873	669.9346541;
21.52631579	873.2	671.3037736; 32.52631579	873.6	671.9083388;
12.52631579	873.8	682.2029006; 25.52631579	873.9	670.7926265;
25.52631579	874	670.8879859; 10.52631579	874	686.5680367;
7.526315789	874.1	694.4805411; 16.52631579	874.2	676.5332858;
18.52631579	874.5	674.7355967; 32.52631579	874.6	672.8224893;
9.526315789	874.8	689.8928921; 6.526315789	875.3	699.0624081;
19.52631579	875.5	674.9034262; 11.52631579	875.9	686.5703321;
27.52631579	876.7	673.4181835; 25.52631579	878.4	675.0896043;
23.52631579	878.4	675.5536386; 24.52631579	878.4	675.2697611;
6.526315789	878.7	703.3870771; 44.52631579	878.7	685.5780074;
9.526315789	878.9	694.778271; 6.526315789	879.1	703.8978036;
15.52631579	879.3	683.2751254; 38.52631579	879.4	680.8793779;
13.52631579	879.5	686.7254898; 10.52631579	879.6	693.1088383;
22.52631579	879.8	677.3234406; 9.526315789	880	696.094878;
12.52631579	880	689.1814544; 19.52631579	880.3	679.7777148;
7.526315789	880.5	702.4440222; 39.52631579	880.6	682.7439251;
19.52631579	880.6	680.0831005; 5.526315789	880.7	709.4583698;
43.52631579	881.5	687.09696; 6.526315789	882.2	707.8699498;
24.52631579	882.5	679.2289566; 24.52631579	882.6	679.3256596;
26.52631579	882.8	679.187438; 36.52631579	883	682.6913003;
17.52631579	884.1	685.7383922; 28.52631579	884.2	680.5517576;
6.526315789	884.2	710.4459174; 17.52631579	884.7	686.3680989;
10.52631579	884.9	699.3550116; 11.52631579	885.7	697.871526;
40.52631579	886	688.407086; 34.52631579	886.4	684.5756912;
47.52631579	886.4	695.5307077; 33.52631579	887.2	684.8033203;
10.52631579	887.9	702.9151452; 6.526315789	888	715.3693895;
7.526315789	888.2	712.1562534; 24.52631579	888.4	684.9457793;
23.52631579	888.5	685.4184745; 9.526315789	889	706.96292;
9.526315789	889.1	707.0846505; 17.52631579	889.6	691.5265141;
31.52631579	889.7	686.3115307; 12.52631579	890.1	700.6880081;
32.52631579	890.5	687.4007833; 16.52631579	890.6	693.957379;
23.52631579	890.7	687.577056; 23.52631579	890.9	687.7734678;
9.526315789	891.1	709.5238371; 30.52631579	891.1	687.3339816;
27.52631579	891.5	687.4010482; 32.52631579	892	688.7804082;
14.52631579	892.1	698.8939911; 28.52631579	892.4	688.2616918;
18.52631579	892.8	693.6659256; 13.52631579	893.1	701.9709891;
22.52631579	893.8	691.1719835; 25.52631579	893.9	689.9838444;
24.52631579	895.1	691.4662561; 19.52631579	895.4	695.2605053;
50.52631579	895.7	707.1325902; 51.52631579	895.7	708.2827265;
52.52631579	895.7	709.4514595; 53.52631579	895.7	710.637075;
54.52631579	895.7	711.8379434; 55.52631579	895.7	713.0525159;
39.52631579	895.8	696.3858344; 45.52631579	896.3	702.2621962;
26.52631579	896.4	692.1757149; 26.52631579	897.3	693.0390082;
24.52631579	897.6	693.9072003; 20.52631579	897.9	696.8398733;
17.52631579	897.9	700.3298425; 26.52631579	898	693.7107896;
22.52631579	898.3	695.6567321; 29.52631579	898.8	694.3582853;
10.52631579	898.9	716.1255153; 16.52631579	899.1	703.1234648;
15.52631579	899.1	704.8188023; 17.52631579	899.2	701.7163118;
32.52631579	899.2	695.4133167; 24.52631579	899.5	695.765246;
29.52631579	899.5	695.0155524; 11.52631579	900	714.6824429;
38.52631579	900.1	699.5052346; 14.52631579	900.2	707.9395529;
13.52631579	900.3	710.164123; 32.52631579	900.3	696.4282596;
20.52631579	900.4	699.3985038; 10.52631579	900.8	718.432842;
11.52631579	901	715.8728138; 27.52631579	901.1	696.5325705;
40.52631579	901.4	702.2149654; 22.52631579	902.5	699.8576543;
26.52631579	903.2	698.710317; 19.52631579	903.3	703.4546716;
11.52631579	903.7	719.0967361; 11.52631579	904.6	720.1746171;
9.526315789	904.6	726.2219729; 31.52631579	905	700.4911844;
31.52631579	905.2	700.677135; 16.52631579	905.2	709.7610904;
31.52631579	905.8	701.235081; 29.52631579	905.8	700.9411598;
23.52631579	905.9	702.5905725; 10.52631579	906.5	725.4012662;
11.52631579	907.2	723.2976831; 20.52631579	907.2	706.3893253;
25.52631579	907.6	703.2750529; 25.52631579	907.8	703.470002;
33.52631579	907.8	703.7029581; 6.526315789	909.8	744.385674;
11.52631579	910.1	726.7973644; 19.52631579	910.4	710.8765425;
9.526315789	910.4	733.5251782; 14.52631579	910.9	720.0476169;
19.52631579	910.9	711.4013074; 11.52631579	911	727.8869934;
27.52631579	911.3	706.2905048; 9.526315789	911.5	734.9193085;
6.526315789	911.6	746.8428148; 37.52631579	911.6	709.2245859;
18.52631579	912.3	714.2503545; 19.52631579	912.4	712.9772799;
43.52631579	912.6	714.873639; 25.52631579	914.5	710.0164888;
23.52631579	915	711.6654706; 25.52631579	915.1	710.6042436;
12.52631579	915.4	730.3133034; 39.52631579	915.6	714.216835;
18.52631579	915.9	718.1000167; 31.52631579	916.3	711.02238;
10.52631579	916.4	737.6744267; 26.52631579	916.4	711.4758382;
26.52631579	916.5	711.5729647; 18.52631579	916.7	718.9576642;
27.52631579	917	711.7693561; 35.52631579	917.6	713.5656551;
6.526315789	917.7	755.2426549; 7.526315789	917.7	750.7868074;
18.52631579	918.3	720.675344; 7.526315789	918.4	751.732523;
13.52631579	918.7	731.5092947; 31.52631579	919	713.5463556;
24.52631579	919.2	715.1844627; 18.52631579	919.5	721.9657014;
22.52631579	919.8	717.3215839; 12.52631579	920.2	736.0714147;
25.52631579	920.4	715.8069921; 12.52631579	920.5	736.4328206;
18.52631579	920.9	723.4734045; 6.526315789	921.1	759.9742484;
33.52631579	921.1	715.9787522; 46.52631579	921.2	725.5043225;
33.52631579	921.8	716.6265221; 7.526315789	923.8	759.0758932;
11.52631579	923.9	743.6930211; 40.52631579	925.1	723.5397962;
23.52631579	925.3	722.0191644; 18.52631579	925.6	728.5531768;
30.52631579	926.3	720.3201594; 32.52631579	926.6	720.8255123;
17.52631579	926.8	731.667675; 24.52631579	928.2	724.1539071;
37.52631579	928.2	724.3107963; 12.52631579	928.8	746.5042661;
38.52631579	928.8	725.4700253; 6.526315789	929.7	772.1058312;
11.52631579	931.1	752.6727954; 16.52631579	931.1	738.5329328;
33.52631579	931.3	725.4347772; 34.52631579	931.4	725.8352492;
5.526315789	931.6	780.1757769;20.52631579	931.8	732.0817807;
14.52631579	932.3	744.8404455;28.52631579	932.5	726.4584625;
19.52631579	932.6	734.4535846;10.52631579	933.1	758.8918496;
7.526315789	933.2	772.0658491;11.52631579	933.5	755.6920436;
10.52631579	933.7	759.6666752;29.52631579	933.9	727.6060043;
32.52631579	935.2	728.8605442;14.52631579	935.3	748.3808084;
19.52631579	935.8	737.9005989;17.52631579	935.9	741.7711471;
27.52631579	936.2	730.3677571;18.52631579	936.3	740.2249282;
20.52631579	936.6	737.172303;20.52631579	936.6	737.172303;
21.52631579	936.6	735.7678915;22.52631579	936.6	734.5411966;
10.52631579	936.6	763.4242913;21.52631579	936.8	735.9774254;
17.52631579	936.9	742.8887046;12.52631579	936.9	756.4714808;
11.52631579	937	760.1188728;10.52631579	937.9	765.1155814;
31.52631579	937.9	731.3007997;12.52631579	938	757.8358805;
31.52631579	938	731.3951535;25.52631579	938.4	733.6280362;
19.52631579	938.5	740.8189138;24.52631579	938.5	734.4983232;
11.52631579	938.8	762.406632;18.52631579	939.5	743.745256;
14.52631579	939.7	753.6033791;19.52631579	940.1	742.5526056;
20.52631579	940.5	741.327846;19.52631579	940.5	742.9865343;
12.52631579	940.6	761.0713003;17.52631579	941	747.4860858;
17.52631579	941.2	747.7109864;27.52631579	941.3	735.3466602;
18.52631579	941.8	746.2841392;19.52631579	942.1	744.7242821;
17.52631579	942.1	748.7237789;7.526315789	942.4	785.0438026;
23.52631579	943.2	740.231031;20.52631579	943.6	744.6436466;
20.52631579	944.2	745.2867252;16.52631579	944.6	753.9340651;
18.52631579	945	749.8286804;13.52631579	945.7	763.9782323;
18.52631579	945.7	750.6059551;17.52631579	947.2	754.4860153;
21.52631579	947.5	747.2502807;10.52631579	947.7	778.0045393;
10.52631579	948	778.403045;24.52631579	948.6	744.7275659;
31.52631579	948.8	741.6121082;28.52631579	949.1	742.532629;
21.52631579	949.1	748.9467241;21.52631579	949.6	749.4774483;
13.52631579	949.6	768.7895214;17.52631579	949.6	757.2113966;
11.52631579	949.8	776.5553495;22.52631579	950.1	748.5771547;
19.52631579	950.8	754.2310935;25.52631579	950.8	746.0476294;
23.52631579	950.9	748.1548915;10.52631579	951.1	782.534938;
25.52631579	951.4	746.6516609;14.52631579	952.1	768.5194216;
25.52631579	952.3	747.5582519;35.52631579	952.8	745.9678227;
18.52631579	953.4	759.2018988;27.52631579	953.4	747.2276198;
26.52631579	953.6	748.0721006;26.52631579	954.3	748.7701548;
17.52631579	954.4	762.6890108;19.52631579	954.5	758.3044105;
17.52631579	955.4	763.83474;27.52631579	955.8	749.5958935;
24.52631579	956.8	753.0973997;18.52631579	957.4	763.7011431;
24.52631579	957.9	754.2247255;12.52631579	958	783.1148474;
15.52631579	958.1	772.599112;26.52631579	959	753.4666255;
21.52631579	959.6	760.1514952;32.52631579	959.8	752.0129611;
24.52631579	959.9	756.2772047;12.52631579	960.5	786.3398408;
25.52631579	960.8	756.1531267;10.52631579	961.2	796.1776686;
13.52631579	961.9	784.1773733;26.52631579	962.1	756.5734864;
14.52631579	962.2	780.8933553;16.52631579	962.9	775.2919892;
11.52631579	963.3	794.3301922;20.52631579	963.6	766.3163035;
26.52631579	963.9	758.3808653;13.52631579	965.1	788.2354741;
32.52631579	966.8	758.6491449;36.52631579	966.9	759.3587052;
12.52631579	967.3	795.1882733;21.52631579	968.6	769.8578111;
13.52631579	969.2	793.4689199;20.52631579	969.9	773.2479817;
17.52631579	970.6	781.449318;12.52631579	972.5	802.0317923;
34.52631579	974	765.5081846;17.52631579	974.6	786.1487717;
7.526315789	975.5	834.0812584;19.52631579	975.6	781.8943794;
26.52631579	976.9	771.5100197;13.52631579	977.2	803.7929941;
24.52631579	977.2	774.1859756;33.52631579	978.7	769.8970382;
21.52631579	978.9	781.0868175;25.52631579	979.5	775.2776214;
28.52631579	981.1	774.0066012;18.52631579	981.7	791.5571587;
19.52631579	982.7	789.9767118;12.52631579	982.9	815.9259503;
24.52631579	983.4	780.6740815;20.52631579	984	788.9541642;
27.52631579	985.7	779.4458502;26.52631579	987.2	782.0102017;
7.526315789	987.8	853.3209354;12.52631579	988.9	824.0714854;
10.52631579	989.5	835.9733862;13.52631579	991.3	822.3654099;
13.52631579	991.4	822.4988999;25.52631579	991.6	787.8189576;
17.52631579	993	808.1287758;17.52631579	998	814.2085702;
33.52631579	998.4	788.6541467;27.52631579	998.9	792.8397732;
14.52631579	999.2	828.1031812;18.52631579	999.4	812.4508463;
25.52631579	1001.4	798.0777007;39.52631579	1004.6	795.3666618;
28.52631579	1006.9	799.898423;21.52631579	1008.3	813.896402;
9.026315789	517.9	517.9;8.026315789	518.1	518.1;
9.026315789	534.5	534.5;8.026315789	537.5	537.5;
8.026315789	544.7	544.7;11.52631579	547.9	547.9;
8.526315789	548.6	548.6;9.026315789	553	553;
8.026315789	557.8	557.8;8.026315789	563.9	563.9;
7.026315789	566.6	566.6;7.526315789	567.7	567.7;
7.526315789	569.4	569.4;9.526315789	570	570;
6.526315789	572.6	572.6;8.026315789	575	575;
8.526315789	575.1	575.1;9.526315789	575.8	575.8;
9.026315789	584.8	584.8;6.526315789	587.7	587.7;
7.026315789	589	589;8.526315789	590.4	590.4;
8.026315789	590.6	590.6;7.526315789	591.6	591.6;
7.526315789	591.8	591.8;7.026315789	592.7	592.7;
6.526315789	594	594;6.526315789	594.8	594.8;
9.526315789	595.4	595.4;9.026315789	597.1	597.1;
7.526315789	597.2	597.2;7.526315789	599.6	599.6;
9.026315789	602.9	602.9;7.026315789	603	603;
8.026315789	603.2	603.2;7.526315789	603.7	603.7;
8.526315789	603.8	603.8;7.026315789	604	604;
6.526315789	604.3	604.3;7.026315789	604.7	604.7;
7.026315789	605.4	605.4;7.526315789	605.4	605.4;
7.026315789	605.5	605.5;7.526315789	607.2	607.2;
7.026315789	608.2	608.2;7.526315789	608.2	608.2;
7.526315789	608.7	608.7;8.526315789	609.1	609.1;
8.526315789	610.1	610.1;7.526315789	611.3	611.3;
9.026315789	616.7	616.7;6.526315789	618.6	618.6;
9.026315789	619.2	619.2;6.026315789	619.4	619.4;
6.026315789	619.5	619.5;7.026315789	619.5	619.5;
7.026315789	621	621;6.526315789	621.9	621.9;
7.026315789	621.9	621.9;7.526315789	622.6	622.6;
6.526315789	622.7	622.7;8.026315789	623.3	623.3;
7.026315789	623.8	623.8;8.526315789	624.8	624.8;
8.026315789	625.4	625.4;6.526315789	626.6	626.6;
8.526315789	627.9	627.9;7.526315789	628.9	628.9;
7.526315789	630.1	630.1;8.026315789	630.3	630.3;
7.026315789	631.7	631.7;8.026315789	632.7	632.7;
7.526315789	633.6	633.6;7.526315789	634.4	634.4;
7.526315789	635.5	635.5;6.026315789	636.3	636.3;
8.026315789	636.9	636.9;7.526315789	639.6	639.6;
7.026315789	640.1	640.1;7.526315789	640.1	640.1;
6.026315789	640.4	640.4;8.026315789	641.5	641.5;
7.526315789	641.8	641.8;6.526315789	642.2	642.2;
8.526315789	642.2	642.2;8.026315789	642.5	642.5;
7.526315789	644.1	644.1;7.026315789	646.7	646.7;
7.526315789	646.7	646.7;6.526315789	647.4	647.4;
5.526315789	649.3	649.3;7.526315789	651.1	651.1;
7.526315789	652.3	652.3;7.526315789	654	654;
7.526315789	656	656;6.526315789	659.7	659.7;
6.526315789	661	661;9.026315789	661.1	661.1;
5.526315789	661.7	661.7;6.026315789	662	662;
7.526315789	677.7	677.7]  
% days, time since start of experiment
tL(:,2:3) = tL(:,2:3)*10^-4; %converting micrometer to centimeter 
tL(:,1) = tL(:,1)-2.68; %rectifying the age to start at zero at the moment of birth
tL1 =  tL(:,1:2); tL2 = [tL(:,1) tL(:,3)]; %splitting orginal data and transformed data
% cm, body length (first dependent variable)
% tL = [tL, 100./tL(:,2).^2]; tL2 = [tL2, 100./tL2(:,2).^2]; tL3 = [tL3, 100./tL3(:,2).^2]; % append weight coefficients for WLS criterion
% conversion coefficients from Kooy2010 

% chemical indices  from Kooy2010 Fig 4.15
%       X     V     E     P
n_O = [1.00, 1.00, 1.00, 1.00;  % C/C, equals 1 by definition
       1.80, 1.80, 1.80, 1.80;  % H/C  these values show that we consider dry-mass
       0.50, 0.50, 0.50, 0.50;  % O/C
       0.15, 0.15, 0.15, 0.15]; % N/C
%       C     H     O     N
n_M = [ 1     0     0     0;    % C/C, equals 0 or 1
        0     2     0     3;    % H/C
        2     1     2     0;    % O/C
        0     0     0     1];   % N/C
    
% specific densities
%       X     V     E     P
d_O = [0.2;  0.2;  0.2;  0.2];    % g/cm^3, specific densities for organics

% chemical potentials from Kooy2010 Tab 4.2
%        X     V     E     P
mu_O = [525; 500;  550;  480] * 1000; % J/mol, chemical potentials for organics

% molecular weights
w_O = n_O' * [12; 1; 16; 14];  % g/mol, mol-weights for organics

% pack coefficients
dwm = [d_O, w_O, mu_O]; % g/cm^3, g/mol, kJ/mol spec density, mol weight, chem pot

% parameters: initial values at T_ref
% edit these values such that predictions are not too far off

T_ref  = 293;      % 1 K, temp for which rate pars are given; don't change this vulue
T_A  = 8000;       % 2 K, Arrhenius temp 
f = 1.0;           % 3 -, scaled functional response
z = 0.02495;         % 4 -, zoom factor; for female
del_M = 0.2411;   % 5 -, shape coefficient
F_m = 6.5;         % 6 l/d.cm^2, {F_m}, max spec searching rate
kap_X = 0.8;       % 7 -, digestion efficiency of food to reserve
v = 0.002826;        % 8 cm/d, energy conductance
kap = 0.08207;      % 9 -, allocation fraction to soma = growth + somatic maintenance
kap_R = 0.95;      %10 -, reproduction efficiency
p_M = 581.3;       %11 J/d.cm^3, [p_M], vol-specific somatic maintenance
p_T =  0;          %12 J/d.cm^2, {p_T}, surface-specific som maintenance
k_J = 0.0001;       %13 1/d, maturity maint rate coefficient
E_G = 3599;        %14 J/cm^3, [E_G], spec cost for structure
E_Hb = 0.002966;    %15 J, E_H^b, maturity at birth
E_Hp = 0.05587;    %16 J, E_H^p, maturity at puberty
h_a = 7.018e-5;    %17 1/d^2, Weibull aging acceleration
s_G = 0;        %18 -, Gompertz stress coefficient
f_tL = 1;      %19 -, functional response for tL-data

% pack parameters and fix T_ref and f and possibly other at well
%   in second column: 0 = fix; 1 = release
pars = [T_ref 0; T_A 0; f    0; z     1; del_M 1; F_m  0;  
        kap_X 0; v   1; kap  1; kap_R 0; p_M   1; p_T  0;  
        k_J   0; E_G 1; E_Hb 1; E_Hp  1; h_a   1; s_G  0; f_tL 0];

txt_pars = { ...    % for presentation of parameter estimates
  'T_ref, K'; 'T_A, K';          'f, -'; 
  'z, -'; 'del_M, -';  '{F_m}, l/d.cm^2'; 
  'kap_X, -'; 'v, cm/d';         'kap, -'; 
  'kap_R, -'; '[p_M], J/d.cm^3'; '{p_T}, J/d.cm^2'; 
  'k_J, 1/d'; '[E_G], J/cm^3';   'E_Hb, J'; 
  'E_Hp, J';  'h_a, 1/d^2';      's_G, -'; 'f_tL, -'};

% estimate parameters, see LikaKear2011
nmregr_options('default'); % set options for parameter estimation
nmregr_options('max_step_number',5e3); % set options for parameter estimation
nmregr_options('max_fun_evals',2e4);   % set options for parameter estimation

%(comment/uncomment whichever is appropriate)
    % pars = nmregr('predict_Rhizoglyphus_robini', pars, Data, tL);    % WLS estimate parameters using overwrite
    pars = nmregr('predict_Rhizoglyphus_robini', pars, Data, tL2);    % WLS estimate parameters using overwrite

sd = 0 * pars(:,1);                                  % initiate standard deviations

%(comment/uncomment whichever is appropriate)
    %  [cov cor sd] = pregr('predict_Rhizoglyphus_robini', pars, Data, tL); % get standard deviation for WLS
    [cov cor sd] = pregr('predict_Rhizoglyphus_robini', pars, Data, tL2); % get standard deviation for WLS
 
 % get FIT
Data(:,3) = 0; Data(1:8,3) = 1; % give unit weight to real data, zero to pseudo-data

%(comment/uncomment whichever is appropriate)
    % [MRE RE] = mre('predict_Rhizoglyphus_robini', pars, Data, tL); % WLS-method
    [MRE RE] = mre('predict_Rhizoglyphus_robini', pars, Data, tL2); % WLS-method

FIT = 10 * (1 - MRE); % get mark for goodness of fit 

% get predictions
t = linspace(0,50,100)'; % times for plotting length data
[Edata EL] = predict_Rhizoglyphus_robini(pars(:,1), Data, t); % notice use of first column of pars only

%% Results

fprintf('FIT = %3.1f \n', FIT)
fprintf('COMPLETE = %3.1f \n\n', COMPLETE)

printpar(txt_data, data, Edata, 'data and expectations'); % for zero-variate data
fprintf('\n') % insert a blank line in screen output
printpar(txt_pars, pars, sd);
close all % remove existing figures, else you get more and more if you retry

figure % one figure to show results of uni-variate data model1(no transformation) and a figure for model2 (transormation dependent on reproduction)
subplot(1,2,1);

%(comment/uncomment whichever is appropriate)
    % plot(tL(:,1), tL(:,2), '.green', t, EL, '-black'); hold on
    plot(tL2(:,1), tL2(:,2), '.blue', t, EL, '-black'); hold on

xlabel('time since birth, d')
ylabel('length, cm')
subplot(1,2,2);
plot(1, Ri, '.black', 1, Edata(8,1),'.red', 'Markersize', 10);
ylabel('reproduction (#/d)'); 
% options.showCode = false; publish('mydata_Pristis_pectinata', options);