
# Code below estimates the parameters d, r_B for mites on yeast and filter paper, and the parameters alpha and beta.
# Estimates for Rm and mu for mites on yeast and filter paper are in the Excel data file

input <- read.table("C:\\Users\\ismalle1\\Documents\\WERK\\Papers\\ms 42 DEB in IPM\\MEE\\Online Supporting Information Data and R scripts\\estimate_d.txt", header=TRUE,  sep = "\t")
attach(input); names(input)
# fit equation L_p = d*L_inf
d <- lm(L_p ~ -1 + L_inf); print(d)
detach(input)

# estimate von Bertalanffy growth rate for yeast diet
input <- read.table("C:\\WERK\\Papers\\ms 42 DEB in IPM\\MEE\\Online Supporting Information Data and R scripts\\estimate_rB_yeast.txt", header=TRUE,  sep = "\t")
names(input)
# fit equation size_t = Linf-(Linf-Lb)*exp(-r_B*age)
Linf = 1.008 ; Lb = 0.166 ;
vBgrowthrate <- nls(size_t~Linf-(Linf-Lb)*exp(-b*age),data=input, start=c(b=0.01))
summary(vBgrowthrate)

# estimate von Bertalanffy growth rate for filter paper diet
input <- read.table("C:\\WERK\\Papers\\ms 42 DEB in IPM\\MEE\\Online Supporting Information Data and R scripts\\estimate_rB_filterpaper.txt", header=TRUE,  sep = "\t")
names(input)
# fit equation size_t = Linf-(Linf-Lb)*exp(-r_B*age)
Linf = 0.642 ; Lb = 0.167;
vBgrowthrate <- nls(size_t~Linf-(Linf-Lb)*exp(-b*age),data=input, start=c(b=0.01))
summary(vBgrowthrate)

# estimate von Bertalanffy growth rate for filter paper AND yeast diet at the same time
input <- read.table("C:\\Users\\ismalle1\\Documents\\WERK\\Papers\\ms 42 DEB in IPM\\MEE\\Online Supporting Information Data and R scripts\\estimate_rB_yeast_FP.txt", header=TRUE,  sep = "\t")
attach(input); names(input)
# fit equation size_t = Linf-(Linf-Lb)*exp(-r_B*age)
Lb = 0.166;
vBgrowthrate <- nls(size_t~a-(a-Lb)*exp(-b*age),data=input, start=c(a=1, b=0.01), nls.control(maxiter = 1000)
summary(vBgrowthrate)
detach(input)

# estimate alpha and beta
input <- read.table("C:\\WERK\\Papers\\ms 42 DEB in IPM\\MEE\\Online Supporting Information Data and R scripts\\estimate_alpha_beta.txt", header=TRUE,  sep = "\t")
attach(input); names(input)
# fit equation 1/r_B = beta + alpha*L_inf
y = 1/r_B;
alpha_beta <- lm(y ~ L_inf); print(alpha_beta)
detach(input)

# estimate mortality rate mu for yeast diet
library(lme4)

input <- read.table("C:\\WERK\\Papers\\ms 42 DEB in IPM\\MEE\\Online Supporting Information Data and R scripts\\estimate_mu_yeast.txt", header=TRUE,  sep = "\t")
attach(input); names(input)
id <- factor(ID)
model1 <- glmer( mortality ~ (1|id),  family=binomial)
summary(model1)
mu <- 1/(1+exp(3.1941)); print(mu)
detach(input)

# estimate mortality rate mu for filter paper diet
library(lme4)

input <- read.table("C:\\WERK\\Papers\\ms 42 DEB in IPM\\MEE\\Online Supporting Information Data and R scripts\\estimate_mu_filterpaper.txt", header=TRUE,  sep = "\t")
attach(input); names(input)
id <- factor(ID)
model1 <- glmer( mortality ~ (1|id),  family=binomial)
summary(model1)
mu <- 1/(1+exp(4.0)); print(mu)
detach(input)