function [E_Y, PopQs] = DEBIPMNotShrink_rays(E_Ymin,E_Ymax,step,MatrixSize)

% Please cite:

% [E_Y, PopQs] = DEBIPMNotShrink_rays(0.65,0.95,15,200);

% input: 
% E_Ymin: minimum feeding level
% E_Ymax: maximum feeding level
% step: step size between E_Ymin and E_Ymax
% MatrixSize: number of size bins of matrix approximation of DEBIPM

Lmin = 100; % used to define limits of matrix approximation
Lb = 130; % disc width at birth in cm 
Lp = 380; % disc width at maturity in cm
Lm = 550; % maximum disc width in cm 
E_Ystdev=0.1; % sigma(Y)

% DEB parameters 
kappa = 0.80; % fraction energy allocation to respiration (as opposed to reproduction)
mu = 0.05; % mortality rate
rb = 0.18; % von Bertalanffy growth rate
Rm = 1; % maximum reproduction rate at L_m

E_Y=linspace(E_Ymin,E_Ymax,step); % Feeding level

        for n=1:length(E_Y); 
            
            Linf = E_Y(n)/E_Ymax*Lm; % ultimate length  
                        
            [S, R, G, D, meshpts] = BigMatrixNotShrink(MatrixSize,Lmin,Linf,Lp,Rm,Lm,E_Y(n),E_Ystdev,rb,kappa,Lb,mu);
            kernelDEB = G*S + D*R; 
            % calculate lambda, ssd, and rv
            [W,d] = eig(kernelDEB); lambda1 = diag(d); imax = find(lambda1==max(lambda1)); 
            V=conj(inv(W)); lambda = lambda1(imax); % population growth rate
            w1=W(:,imax); v1 = real(V(imax,:))';
            ssd = w1/sum(w1); ssd = ssd'; % stable stage distribution
            
            % calculation of LRS 
            [m,p]=size(kernelDEB); TS = G*S; Fmat = D*R; 
            R0mat = Fmat*inv((eye(m)-TS)); meanLRS = max(eig(R0mat)); 

            % calculate generation time using approximation
            GT = log(meanLRS)/log(lambda);

            PopQstemp = [E_Y(n),Lm,Lp,Rm,lambda,meanLRS,GT];
            PopQs(n,:) = PopQstemp;
        end
        hold on
        subplot(3,1,1); plot(E_Y,PopQs(:,5),'r-','LineWidth',2);  axis square;  box off
        ylabel('Population growth rate','FontSize',14); xlabel(' ');  
        hold on
        subplot(3,1,2); plot(E_Y,PopQs(:,6),'r-','LineWidth',2);   axis square;  box off
        ylabel('R_0','FontSize',14);  xlabel(' ');  set(gca,'FontSize',12); 
        hold on
        subplot(3,1,3); plot(E_Y,PopQs(:,7),'r-','LineWidth',2); axis square;  box off; hold on
        ylabel('Generation time','FontSize',14);  xlabel('Feeding level');  set(gca,'FontSize',12);         